# py-handy
A practical and convenient python toolset

## Usage

### install

```shell
pip3 install -U pyhandytools
```

### module

- file
- env

## PYPI url

- ```https://pypi.org/project/pyhandytools/```